/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#include <QLabel>
#include <QToolButton>
#include <QPluginLoader>

//#include "tasksplugin.h"
#include <cprime/cplugininterface.h>
#include "corestuff.h"
#include "pagetasks.h"
#include "ui_pagetasks.h"

pagetasks::pagetasks(QWidget *parent) : QWidget(parent), ui(new Ui::pagetasks)
{
    ui->setupUi(this);

    loadSettings();
    startSetup();
}

pagetasks::~pagetasks()
{
    delete ui;
}

/**
 * @brief Loads application settings
 */
void pagetasks::loadSettings()
{
    listViewIconSize = sm->value("CoreApps", "ListViewIconSize");
    touch = sm->value("CoreApps", "TouchMode");
}

void pagetasks::startSetup()
{
    ui->taskView->setIconSize(listViewIconSize);

    QString x11Plugin = "/usr/lib/coreapps/corestuff/plugins/libx11tasks.so";
    QString wlPlugin = "/usr/lib/coreapps/corestuff/plugins/libwltasks.so";

	/* If XDG_SESSION_TYPE is set to x11 */
	if ( qgetenv( "XDG_SESSION_TYPE" ) == "x11" ) {

        QPluginLoader loader( x11Plugin );
        QObject *pObject = loader.instance();

        if ( pObject ) {
            mTasks = qobject_cast<TasksPlugin *>( pObject );
            if ( !mTasks )
                qWarning() << "Plugin Error:" << loader.errorString();
        }

        else {
            qWarning() << "Plugin Error:" << loader.errorString();
		}
    }

	/* Otherwise we assume its wayland session */
	else {

        // QPluginLoader loader( wlPlugin );
        // QObject *pObject = loader.instance();

        // if ( pObject ) {
            // mTasks = qobject_cast<TasksPlugin *>( pObject );
            // if ( !mTasks )
                // qWarning() << "Plugin Error:" << loader.errorString();
        // }

        // else {
            // qWarning() << "Plugin Error:" << loader.errorString();
		// }
    }

    if ( mTasks ) {
		mTasks->setBackendTarget( ui->taskView );
		mTasks->updateClientList();
		connect( mTasks, SIGNAL( resizeDesktop() ), this, SIGNAL( resizeDesktop() ) );
		connect( mTasks, SIGNAL( activateDock() ), this, SIGNAL( activateDock() ) );
	}
}

void pagetasks::updateClientList() {

	if ( mTasks )
		mTasks->updateClientList();
}

void pagetasks::showDesktop() {

	if ( mTasks )
		mTasks->showDesktop();
}
